
From: Jesse Millan <jessem@cs.pdx.edu>

This patch eliminates the GCC4 warning on the x86_64 platform:

kernel/sched.c:1824: warning: control may reach end of non-void function
'sched_find_first_bit' being inlined.

The change follows the lead of others, i.e.  it is guaranteed that at least
one of b[0], b[1], or b[2] will have a bit set and evaluate to true.  That
being said, GCC4.0.0 notices that the code flow does not return anything if
b[0], b[1] and b[2] are not true.  Since we know better, if it's not b[0] or
b[1], it has to be b[2].

Signed-off-by: Jesse Millan <jessem@cs.pdx.edu>
Signed-off-by: Domen Puncer <domen@coderock.org>
Signed-off-by: Andi Kleen <ak@suse.de>
Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 include/asm-x86_64/bitops.h |    3 +--
 1 files changed, 1 insertion(+), 2 deletions(-)

diff -puN include/asm-x86_64/bitops.h~x86_64-fix-gcc-4-warning-in-sched_find_first_bit include/asm-x86_64/bitops.h
--- devel/include/asm-x86_64/bitops.h~x86_64-fix-gcc-4-warning-in-sched_find_first_bit	2005-07-27 12:36:55.000000000 -0700
+++ devel-akpm/include/asm-x86_64/bitops.h	2005-07-27 12:36:55.000000000 -0700
@@ -348,8 +348,7 @@ static inline int sched_find_first_bit(c
 		return __ffs(b[0]);
 	if (b[1])
 		return __ffs(b[1]) + 64;
-	if (b[2])
-		return __ffs(b[2]) + 128;
+	return __ffs(b[2]) + 128;
 }
 
 /**
_
